Common module for Sirius applications
=====================================
[![Build Status](https://api.travis-ci.org/lnls-sirius/sirius-common.svg)](https://travis-ci.org/lnls-sirius/sirius-common)
![Latest tag](https://img.shields.io/github/tag/lnls-sirius/sirius-common.svg?style=flat)
[![Latest release](https://img.shields.io/github/release/lnls-sirius/sirius-common.svg?style=flat)](https://github.com/lnls-sirius/sirius-common/releases)
[![PyPI version fury.io](https://badge.fury.io/py/siriuscommon.svg)](https://pypi.python.org/pypi/siriuscommon/)

Common features for Sirius scripts.

Available at **PyPi** https://pypi.org/project/siriuscommon/


library for:
* EPICS Archiver Appliance
* Fluig (WIP)
* Taiga
* Zabbix
* utility-api

EPICS Archiver Appliance
------------------------

Fluig
-----

Taiga
-----
The followwing scripts are installed by this module:

| script                   | description                                                    |
| ------------------------ | -------------------------------------------------------------- |
| taiga-initialize-project | Initialise a Taiga project, creating custom attributes         |
| taiga-export-xlsx        | Export a Taiga project into a spreadsheet using the ENG format |


Zabbix
------

utility-api
-----------